@@ -11,7 +11,7 @@ from twisted.python.versions import Version
 from zope.interface.declarations import implementer
 
 import syncplay
-from syncplay.constants import PING_MOVING_AVERAGE_WEIGHT, CONTROLLED_ROOMS_MIN_VERSION, USER_READY_MIN_VERSION, SHARED_PLAYLIST_MIN_VERSION, CHAT_MIN_VERSION
+from syncplay.constants import PING_MOVING_AVERAGE_WEIGHT, CONTROLLED_ROOMS_MIN_VERSION, USER_READY_MIN_VERSION, SHARED_PLAYLIST_MIN_VERSION, CHAT_MIN_VERSION, UNKNOWN_UI_MODE
 from syncplay.messages import getMessage
 from syncplay.utils import meetsMinVersion
 
@@ -105,6 +105,15 @@ class SyncClientProtocol(JSONCommandProtocol):
                 self.dropWithError(getMessage("startTLS-server-certificate-invalid"))
             elif "mismatched_id=DNS_ID" in str(reason.value):
                 self.dropWithError(getMessage("startTLS-server-certificate-invalid-DNS-ID"))
+            elif reason:
+                try:
+                    self._client.ui.showErrorMessage(str(type(reason)))
+                    self._client.ui.showErrorMessage(str(reason))
+                    if reason.stack:
+                        self._client.ui.showErrorMessage(str(reason.stack))
+                    self._client.ui.showErrorMessage(str(reason.value))
+                except:
+                    pass
         except:
             pass
         self._client.destroyProtocol()
@@ -131,6 +140,10 @@ class SyncClientProtocol(JSONCommandProtocol):
             self._client.setUsername(username)
             self._client.setRoom(roomName)
         self.logged = True
+        if self.persistentRoomWarning(featureList):
+            if len(motd) > 0:
+                motd += "\n\n"
+            motd += getMessage("persistent-rooms-notice")
         if motd:
             self._client.ui.showMessage(motd, True, True)
         self._client.ui.showMessage(getMessage("connected-successful-notification"))
@@ -138,6 +151,9 @@ class SyncClientProtocol(JSONCommandProtocol):
         self._client.sendFile()
         self._client.setServerVersion(version, featureList)
 
+    def persistentRoomWarning(self, serverFeatures):
+        return serverFeatures["persistentRooms"] if "persistentRooms" in serverFeatures else False
+
     def sendHello(self):
         hello = {}
         hello["username"] = self._client.getUsername()
@@ -441,6 +457,8 @@ class SyncServerProtocol(JSONCommandProtocol):
             self._features["featureList"] = False
             self._features["readiness"] = meetsMinVersion(self._version, USER_READY_MIN_VERSION)
             self._features["managedRooms"] = meetsMinVersion(self._version, CONTROLLED_ROOMS_MIN_VERSION)
+            self._features["persistentRooms"] = False
+            self._features["uiMode"] = UNKNOWN_UI_MODE
         return self._features
 
     def isLogged(self):
@@ -496,6 +514,11 @@ class SyncServerProtocol(JSONCommandProtocol):
             self._logged = True
             self.sendHello(version)
 
+    def persistentRoomWarning(self, clientFeatures, serverFeatures):
+        serverPersistentRooms = serverFeatures["persistentRooms"]
+        clientPersistentRooms = clientFeatures["persistentRooms"] if "persistentRooms" in clientFeatures else False
+        return serverPersistentRooms and not clientPersistentRooms
+
     @requireLogged
     def handleChat(self, chatMessage):
         if not self._factory.disableChat:
@@ -520,8 +543,12 @@ class SyncServerProtocol(JSONCommandProtocol):
             hello["room"] = {"name": room.getName()}
         hello["version"] = clientVersion  # Used so 1.2.X client works on newer server
         hello["realversion"] = syncplay.version
-        hello["motd"] = self._factory.getMotd(userIp, username, room, clientVersion)
         hello["features"] = self._factory.getFeatures()
+        hello["motd"] = self._factory.getMotd(userIp, username, room, clientVersion)
+        if self.persistentRoomWarning(clientFeatures=self._features, serverFeatures=hello["features"]):
+            if len(hello["motd"]) > 0:
+                hello["motd"] += "\n\n"
+            hello["motd"] += getMessage("persistent-rooms-notice")
         self.sendMessage({"Hello": hello})
 
     @requireLogged
@@ -617,11 +644,28 @@ class SyncServerProtocol(JSONCommandProtocol):
             }
             userlist[room.getName()][watcher.getName()] = userFile
 
+    def _addDummyUserOnList(self, userlist, dummyRoom,dummyCount):
+        if dummyRoom not in userlist:
+            userlist[dummyRoom] = {}
+        dummyFile = {
+            "position": 0,
+            "file": {},
+            "controller": False,
+            "isReady": True,
+            "features": []
+        }
+        userlist[dummyRoom][" " * dummyCount] = dummyFile
+
     def sendList(self):
         userlist = {}
         watchers = self._factory.getAllWatchersForUser(self._watcher)
+        dummyCount = 0
         for watcher in watchers:
             self._addUserOnList(userlist, watcher)
+        if self._watcher.isGUIUser(self.getFeatures()):
+            for emptyRoom in self._factory.getEmptyPersistentRooms():
+                dummyCount += 1
+                self._addDummyUserOnList(userlist, emptyRoom, dummyCount)
         self.sendMessage({"List": userlist})
 
     @requireLogged
