@@ -18,6 +18,7 @@ class ConsoleUI(threading.Thread):
         self.PromptResult = ""
         self.promptMode.set()
         self._syncplayClient = None
+        self.uiMode = constants.CONSOLE_UI_MODE
         threading.Thread.__init__(self, name="ConsoleUI")
 
     def addClient(self, client):
@@ -193,8 +194,10 @@ class ConsoleUI(threading.Thread):
             if filename is None:
                 self.showErrorMessage("No file/url given")
                 return
-
             self._syncplayClient.ui.addFileToPlaylist(filename)
+        elif command.group('command') in constants.COMMANDS_QUEUEANDSELECT:
+            self._syncplayClient.playlist.switchToNewPlaylistItem = True
+            self.executeCommand("{} {}".format(constants.COMMANDS_QUEUE[0], command.group('parameter')))
         elif command.group('command') in constants.COMMANDS_PLAYLIST:
             playlist = self._syncplayClient.playlist
             playlist_elements = ["\t{}: {}".format(i+1, el) for i, el in enumerate(playlist._playlist)]
@@ -225,6 +228,8 @@ class ConsoleUI(threading.Thread):
 
             except (TypeError, AttributeError):
                 self.showErrorMessage(getMessage("playlist-invalid-index-error"))
+        elif command.group('command') in constants.COMMANDS_NEXT:
+            self._syncplayClient.playlist.loadNextFileInPlaylist()
 
         else:
             if self._tryAdvancedCommands(data):
@@ -237,14 +242,17 @@ class ConsoleUI(threading.Thread):
             self.showMessage(getMessage("commandlist-notification/undo"), True)
             self.showMessage(getMessage("commandlist-notification/pause"), True)
             self.showMessage(getMessage("commandlist-notification/seek"), True)
+            self.showMessage(getMessage("commandlist-notification/offset"), True)
             self.showMessage(getMessage("commandlist-notification/help"), True)
             self.showMessage(getMessage("commandlist-notification/toggle"), True)
             self.showMessage(getMessage("commandlist-notification/create"), True)
             self.showMessage(getMessage("commandlist-notification/auth"), True)
             self.showMessage(getMessage("commandlist-notification/chat"), True)
             self.showMessage(getMessage("commandList-notification/queue"), True)
+            self.showMessage(getMessage("commandList-notification/queueandselect"), True)
             self.showMessage(getMessage("commandList-notification/playlist"), True)
             self.showMessage(getMessage("commandList-notification/select"), True)
+            self.showMessage(getMessage("commandList-notification/next"), True)
             self.showMessage(getMessage("commandList-notification/delete"), True)
             self.showMessage(getMessage("syncplay-version-notification").format(syncplay.version), True)
             self.showMessage(getMessage("more-info-notification").format(syncplay.projectURL), True)
